@@ -115,6 +115,13 @@ class ScormXBlock(XBlock):
         scope=Scope.settings,
     )
 
+    fullscreen_on_launch = Boolean(
+        display_name=_("Fullscreen on launch"),
+        help=_("Display in fullscreen mode on launch"),
+        default=False,
+        scope=Scope.settings,
+    )
+
     has_author_view = True
 
     def render_template(self, template_path, context):
@@ -149,7 +156,11 @@ class ScormXBlock(XBlock):
         frag.add_css(self.resource_string("static/css/scormxblock.css"))
         frag.add_javascript(self.resource_string("static/js/src/scormxblock.js"))
         frag.initialize_js(
-            "ScormXBlock", json_args={"scorm_version": self.scorm_version}
+            "ScormXBlock",
+            json_args={
+                "scorm_version": self.scorm_version,
+                "fullscreen_on_launch": self.fullscreen_on_launch,
+            },
         )
         return frag
 
@@ -162,6 +173,7 @@ class ScormXBlock(XBlock):
             "field_weight": self.fields["weight"],
             "field_width": self.fields["width"],
             "field_height": self.fields["height"],
+            "field_fullscreen_on_launch": self.fields["fullscreen_on_launch"],
             "scorm_xblock": self,
         }
         studio_context.update(context or {})
@@ -183,9 +195,10 @@ class ScormXBlock(XBlock):
         self.display_name = request.params["display_name"]
         self.width = request.params["width"]
         self.height = request.params["height"]
-        self.has_score = request.params["has_score"]
+        self.has_score = request.params["has_score"] == "1"
         self.weight = request.params["weight"]
-        self.icon_class = "problem" if self.has_score == "True" else "video"
+        self.fullscreen_on_launch = request.params["fullscreen_on_launch"] == "1"
+        self.icon_class = "problem" if self.has_score else "video"
 
         response = {"result": "success", "errors": []}
         if not hasattr(request.params["file"], "file"):
@@ -264,8 +277,7 @@ class ScormXBlock(XBlock):
                             os.path.relpath(zipinfo.filename, root_path),
                         )
                         self.storage.save(
-                            dest_path,
-                            scorm_zipfile.open(zipinfo.filename),
+                            dest_path, scorm_zipfile.open(zipinfo.filename),
                         )
 
     @property
@@ -513,14 +525,15 @@ class ScormXBlock(XBlock):
         Return the storage backend used to store the assets of this xblock. This is a cached property.
         """
         if not getattr(self, "_storage", None):
+
             def get_default_storage(_xblock):
                 return default_storage
-        
+
             storage_func = self.xblock_settings.get("STORAGE_FUNC", get_default_storage)
             if isinstance(storage_func, string_types):
                 storage_func = import_string(storage_func)
             self._storage = storage_func(self)
-        
+
         return self._storage
 
     @property
